/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.fujitsu.fgcp.domain;

import com.google.common.base.Objects;

/**
 * Holds information relating to the FGCP service.
 */
public class Information {
   private int seqno;
   private String title;
   private String message;
   private String startDate;
   private String expiry;
   private String entryDate;

   /**
    * @return the seqno
    */
   public int getSeqno() {
      return seqno;
   }

   /**
    * @return the title
    */
   public String getTitle() {
      return title;
   }

   /**
    * @return the message
    */
   public String getMessage() {
      return message;
   }

   /**
    * @return the startDate
    */
   public String getStartDate() {
      return startDate;
   }

   /**
    * @return the expiry
    */
   public String getExpiry() {
      return expiry;
   }

   /**
    * @return the entryDate
    */
   public String getEntryDate() {
      return entryDate;
   }

   @Override
   public int hashCode() {
      return Objects.hashCode(seqno, entryDate, message, title);
   }

   @Override
   public boolean equals(Object obj) {
      if (this == obj)
         return true;
      if (obj == null)
         return false;
      if (getClass() != obj.getClass())
         return false;
      Information that = Information.class.cast(obj);
      return Objects.equal(this.seqno, that.seqno)
            && Objects.equal(this.entryDate, that.entryDate)
            && Objects.equal(this.message, that.message)
            && Objects.equal(this.title, that.title);
   }

   @Override
   public String toString() {
      return Objects.toStringHelper(this).omitNullValues()
            .add("seqno", seqno).add("entryDate", entryDate)
            .add("title", title).add("message", message)
            .add("startDate", startDate).add("expiry", expiry).toString();
   }
}
